@@ -10,13 +10,16 @@ add_task(async function() {
   requestLongerTimeout(2);
   let newWin = await BrowserTestUtils.openNewBrowserWindow();
 
-  await BrowserTestUtils.withNewTab({
-    gBrowser,
-    url: "about:blank",
-  }, async function(browser) {
-    ok(true, "Collecting baseline coverage for browser-chrome tests.");
-    await new Promise((c) => setTimeout(c, 30 * 1000));
-  });
+  await BrowserTestUtils.withNewTab(
+    {
+      gBrowser,
+      url: "about:blank",
+    },
+    async function(browser) {
+      ok(true, "Collecting baseline coverage for browser-chrome tests.");
+      await new Promise(c => setTimeout(c, 30 * 1000));
+    }
+  );
 
   await BrowserTestUtils.closeWindow(newWin);
 });
